==> xpose4_4.5.0.tar.gz: xpose4/R/change.cat.levels.R <==
# Xpose 4
# An R-based population pharmacokinetic/
# pharmacodynamic model building aid for NONMEM.
# Copyright (C) 1998-2004 E. Niclas Jonsson and Mats Karlsson.
# Copyright (C) 2005-2008 Andrew C. Hooker, Justin J. Wilkins, 
# Mats O. Karlsson and E. Niclas Jonsson.
# Copyright (C) 2009-2010 Andrew C. Hooker, Mats O. Karlsson and 
# E. Niclas Jonsson.

# This file is a part of Xpose 4.
# Xpose 4 is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License
# as published by the Free Software Foundation, either version 3
# of the License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.

# You should have received a copy of the GNU Lesser General Public License
# along with this program.  A copy can be cound in the R installation
# directory under \share\licenses. If not, see http://www.gnu.org/licenses/.

change.cat.levels <- function(object,
                              classic = FALSE,
                              cat.limit=NULL,
                              ...){
                              
  if(is.null(cat.limit)){
    cat("\nPlease type the number of unique data values beneath which a\n")
    cat("variable will be treated as categorical (it is currently\n")
    cat("set to ",object@Prefs@Cat.levels,".) (0=exit):\n",sep="")
    ans <- readline()
  } else {
    ans <- cat.limit
  }
  
  ans <- as.numeric(ans)
  if (is.na(ans)){
    cat(paste("The data value must be numeric\n",
              "Nothing has been changed\n"))
    return(object)
  }
  if(ans == 0) {
    cat(paste("Nothing has been changed\n"))
    return(object)
  }
  if (ans<0){
    cat(paste("The data value must be greater than zero\n",
              "Nothing has been changed\n"))
    return(object)
  }

    
  if (!is.na(ans)) {
    object@Prefs@Cat.levels <- ans
    Data(object) <- object@Data
    if (classic==TRUE) {
      c1<-call("assign",paste("xpdb", object@Runno, sep = ""), data, immediate=T, envir = .GlobalEnv)
      eval(c1)
      c2<-call("assign",pos = 1, ".cur.db", eval(as.name(paste("xpdb", object@Runno, sep = ""))))
      eval(c2)
    }
  }
  return(object)
}
    

"change.cat.levels<-" <-
  function(object,
           classic=FALSE,
           ...,
           value){
    object <- change.cat.levels(object,calssic=classic,cat.limit=value,...)
    return(object)
  }

==> xpose4_4.6.1.tar.gz: xpose4/R/change.cat.levels.R <==
#' @describeIn change_misc_parameters change settings for the number of unique data
#' values required in a variable in order to define it as continuous for ordinary
#' variables.
#' @export
change.cat.levels <- function(object,
                              classic = FALSE,
                              cat.limit=NULL,
                              ...){
                              
  if(is.null(cat.limit)){
    cat("\nPlease type the number of unique data values beneath which a\n")
    cat("variable will be treated as categorical (it is currently\n")
    cat("set to ",object@Prefs@Cat.levels,".) (0=exit):\n",sep="")
    ans <- readline()
  } else {
    ans <- cat.limit
  }
  
  ans <- as.numeric(ans)
  if (is.na(ans)){
    cat(paste("The data value must be numeric\n",
              "Nothing has been changed\n"))
    return(object)
  }
  if(ans == 0) {
    cat(paste("Nothing has been changed\n"))
    return(object)
  }
  if (ans<0){
    cat(paste("The data value must be greater than zero\n",
              "Nothing has been changed\n"))
    return(object)
  }

    
  if (!is.na(ans)) {
    object@Prefs@Cat.levels <- ans
    Data(object) <- object@Data
    if (classic==TRUE) {
      c1<-call("assign",paste("xpdb", object@Runno, sep = ""), data, immediate=T, envir = .GlobalEnv)
      eval(c1)
      c2<-call("assign",pos = 1, ".cur.db", eval(as.name(paste("xpdb", object@Runno, sep = ""))))
      eval(c2)
    }
  }
  return(object)
}
    
#' @describeIn change_misc_parameters change settings for the number of unique data
#' values required in a variable in order to define it as continuous for ordinary
#' variables.
#' @export
"change.cat.levels<-" <-
  function(object,
           classic=FALSE,
           ...,
           value){
    object <- change.cat.levels(object,calssic=classic,cat.limit=value,...)
    return(object)
  }
